summaryrefslogtreecommitdiff
path: root/utils/lib_sxng_static.sh
diff options
context:
space:
mode:
Diffstat (limited to 'utils/lib_sxng_static.sh')
-rwxr-xr-xutils/lib_sxng_static.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/utils/lib_sxng_static.sh b/utils/lib_sxng_static.sh
index 1d76bfe70..de34ea629 100755
--- a/utils/lib_sxng_static.sh
+++ b/utils/lib_sxng_static.sh
@@ -82,9 +82,9 @@ static.build.commit() {
build_msg STATIC "build & commit /static files"
# check for not commited files
if [ -n "$(git diff --name-only)" ]; then
- err_msg "some files are not commited:"
+ err_msg "some files are not committed:"
git diff --name-only | prefix_stdout " "
return 1
fi
@@ -82,9 +82,9 @@ static.build.commit() {
build_msg STATIC "build & commit /static files"
- # check for not commited files
+ # check for not committed files
if [ -n "$(git diff --name-only)" ]; then